@@ -41,18 +41,18 @@ public:
     KOrganizerPlugin(KontactInterface::Core *core, const QVariantList &);
     ~KOrganizerPlugin() override;
 
-    bool isRunningStandalone() const override;
+    Q_REQUIRED_RESULT bool isRunningStandalone() const override;
     int weight() const override
     {
         return 400;
     }
 
-    bool canDecodeMimeData(const QMimeData *) const override;
+    Q_REQUIRED_RESULT bool canDecodeMimeData(const QMimeData *) const override;
     void processDropEvent(QDropEvent *) override;
 
     KontactInterface::Summary *createSummaryWidget(QWidget *parent) override;
 
-    QStringList invisibleToolbarActions() const override;
+    Q_REQUIRED_RESULT QStringList invisibleToolbarActions() const override;
 
     void select() override;
 
